# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`nhc`](#nhc): Manage Node Health Check (NHC)
* [`nhc::config`](#nhcconfig): private class
* [`nhc::install`](#nhcinstall): private class

### Defined types

* [`nhc::conf`](#nhcconf): Manage NHC configurations
* [`nhc::custom_check`](#nhccustom_check): Add NHC custom check file

## Classes

### <a name="nhc"></a>`nhc`

Manage Node Health Check (NHC)

#### Examples

##### 

```puppet
include ::nhc
```

#### Parameters

The following parameters are available in the `nhc` class:

* [`ensure`](#ensure)
* [`install_method`](#install_method)
* [`package_ensure`](#package_ensure)
* [`version`](#version)
* [`package_release`](#package_release)
* [`install_source`](#install_source)
* [`package_name`](#package_name)
* [`repo_name`](#repo_name)
* [`source_dependencies`](#source_dependencies)
* [`libexec_dir`](#libexec_dir)
* [`checks`](#checks)
* [`settings`](#settings)
* [`settings_host`](#settings_host)
* [`config_overrides`](#config_overrides)
* [`detached_mode`](#detached_mode)
* [`detached_mode_fail_nodata`](#detached_mode_fail_nodata)
* [`program_name`](#program_name)
* [`conf_dir`](#conf_dir)
* [`conf_file`](#conf_file)
* [`include_dir`](#include_dir)
* [`log_file`](#log_file)
* [`sysconfig_path`](#sysconfig_path)
* [`manage_logrotate`](#manage_logrotate)
* [`log_rotate_every`](#log_rotate_every)
* [`custom_checks`](#custom_checks)

##### <a name="ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`

State of NHC resources

Default value: `'present'`

##### <a name="install_method"></a>`install_method`

Data type: `Enum['repo','package','source']`

The method used to install NHC.
Using `repo` will require the `Yumrepo` resource if `repo_name` is defined.

Default value: `'source'`

##### <a name="package_ensure"></a>`package_ensure`

Data type: `Optional[String]`

The ensure state of package if using `install_method` of `repo` or `package`.

Default value: ``undef``

##### <a name="version"></a>`version`

Data type: `Optional[String]`

The version of NHC to install.

Default value: `'1.4.2'`

##### <a name="package_release"></a>`package_release`

Data type: `Optional[String]`

The package release NHC to install. Not used if `install_method` is `source`.

Default value: `'1'`

##### <a name="install_source"></a>`install_source`

Data type: `Optional[Variant[Stdlib::HTTPUrl,Stdlib::HTTPSUrl]]`

The source of install.
For `install_method` of `package` this is URL to package
For `install_method` of `source` this is git source URL

Default value: ``undef``

##### <a name="package_name"></a>`package_name`

Data type: `Optional[String]`

Name of the NHC package, not used with `install_method` of `source`.

Default value: ``undef``

##### <a name="repo_name"></a>`repo_name`

Data type: `Optional[String]`

The repo name for NHC, only used with `install_method` of `repo`.

Default value: ``undef``

##### <a name="source_dependencies"></a>`source_dependencies`

Data type: `Array`

The package dependencies for source install.

Default value: `['automake','make']`

##### <a name="libexec_dir"></a>`libexec_dir`

Data type: `Stdlib::Absolutepath`

Location for libexec directory, OS dependent.

Default value: `'/usr/libexec'`

##### <a name="checks"></a>`checks`

Data type: `Variant[Hash, Array]`

NHC checks for nhc.conf

Default value: `[]`

##### <a name="settings"></a>`settings`

Data type: `Hash`

Settings to add to nhc.conf

Default value: `{}`

##### <a name="settings_host"></a>`settings_host`

Data type: `Hash`

Host specific settings for nhc.conf

Default value: `{}`

##### <a name="config_overrides"></a>`config_overrides`

Data type: `Hash`

Settings to add to /etc/sysconfig/nhc

Default value: `{}`

##### <a name="detached_mode"></a>`detached_mode`

Data type: `Boolean`

Value for DETACHED_MODE

Default value: ``false``

##### <a name="detached_mode_fail_nodata"></a>`detached_mode_fail_nodata`

Data type: `Boolean`

Value for DETACHED_MODE_FAIL_NODATA

Default value: ``false``

##### <a name="program_name"></a>`program_name`

Data type: `String`

Value for NAME

Default value: `'nhc'`

##### <a name="conf_dir"></a>`conf_dir`

Data type: `Stdlib::Absolutepath`

Path to NHC configuration directry

Default value: `'/etc/nhc'`

##### <a name="conf_file"></a>`conf_file`

Data type: `Stdlib::Absolutepath`

Path for this configuration file

Default value: `'/etc/nhc/nhc.conf'`

##### <a name="include_dir"></a>`include_dir`

Data type: `Stdlib::Absolutepath`

Path to directory containing NHC checks

Default value: `'/etc/nhc/scripts'`

##### <a name="log_file"></a>`log_file`

Data type: `Stdlib::Absolutepath`

Path to log file

Default value: `'/var/log/nhc.log'`

##### <a name="sysconfig_path"></a>`sysconfig_path`

Data type: `Stdlib::Absolutepath`

Path to sysconfig file

Default value: `'/etc/sysconfig/nhc'`

##### <a name="manage_logrotate"></a>`manage_logrotate`

Data type: `Boolean`

Boolean that sets if logrotate resources should be managed

Default value: ``true``

##### <a name="log_rotate_every"></a>`log_rotate_every`

Data type: `String`

Frequency of logrotation

Default value: `'weekly'`

##### <a name="custom_checks"></a>`custom_checks`

Data type: `Hash`

Hash passed to `nhc::custom_check`

Default value: `{}`

### <a name="nhcconfig"></a>`nhc::config`

private class

### <a name="nhcinstall"></a>`nhc::install`

private class

## Defined types

### <a name="nhcconf"></a>`nhc::conf`

Manage NHC configurations

#### Examples

##### Define additional NHC configuration

```puppet
nhc::conf { 'nhc-cron':
  settings          => { 'NHC_RM' => 'slurm' },
  settings_host     => { 'c0001' => { 'FOO' => 'bar' }},
  checks            => { '*' => ['check_fs_free /tmp 10%'] },
  config_overrides  => { 'HOSTNAME' => '"$HOSTNAME_S"' },
}
```

#### Parameters

The following parameters are available in the `nhc::conf` defined type:

* [`ensure`](#ensure)
* [`checks`](#checks)
* [`settings`](#settings)
* [`settings_host`](#settings_host)
* [`config_overrides`](#config_overrides)
* [`detached_mode`](#detached_mode)
* [`detached_mode_fail_nodata`](#detached_mode_fail_nodata)
* [`program_name`](#program_name)
* [`conf_dir`](#conf_dir)
* [`conf_file`](#conf_file)
* [`include_dir`](#include_dir)
* [`sysconfig_path`](#sysconfig_path)
* [`log_file`](#log_file)

##### <a name="ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`

State of nhc::conf

Default value: `'present'`

##### <a name="checks"></a>`checks`

Data type: `Variant[Hash, Array]`

Checks to add to the configuration file

Default value: `[]`

##### <a name="settings"></a>`settings`

Data type: `Hash`

Settings to add to the configuration file

Default value: `{}`

##### <a name="settings_host"></a>`settings_host`

Data type: `Hash`

Settings specific to a hosts to add to the configuration file

Default value: `{}`

##### <a name="config_overrides"></a>`config_overrides`

Data type: `Hash`

Overrides for configuration in /etc/sysconfig/$name

Default value: `{}`

##### <a name="detached_mode"></a>`detached_mode`

Data type: `Boolean`

Value for DETACHED_MODE

Default value: ``false``

##### <a name="detached_mode_fail_nodata"></a>`detached_mode_fail_nodata`

Data type: `Boolean`

Value for DETACHED_MODE_FAIL_NODATA

Default value: ``false``

##### <a name="program_name"></a>`program_name`

Data type: `String`

Value for NAME

Default value: `$name`

##### <a name="conf_dir"></a>`conf_dir`

Data type: `Optional[Stdlib::Absolutepath]`

Path to NHC configuration directry. Defaults to `/etc/nhc`

Default value: ``undef``

##### <a name="conf_file"></a>`conf_file`

Data type: `Optional[Stdlib::Absolutepath]`

Path for this configuration file. Defaults to `/etc/nhc/$name.conf`

Default value: ``undef``

##### <a name="include_dir"></a>`include_dir`

Data type: `Optional[Stdlib::Absolutepath]`

Path to directory containing NHC checks. Defaults to `/etc/nhc/scripts`

Default value: ``undef``

##### <a name="sysconfig_path"></a>`sysconfig_path`

Data type: `Optional[Stdlib::Absolutepath]`

Path to sysconfig file. Defaults to `/etc/sysconfig/$name`

Default value: ``undef``

##### <a name="log_file"></a>`log_file`

Data type: `Optional[Stdlib::Absolutepath]`

Path to log file. Defaults to `/var/log/$name.log`

Default value: ``undef``

### <a name="nhccustom_check"></a>`nhc::custom_check`

Add NHC custom check file

#### Examples

##### Define custom NHC check file

```puppet
nhc::custom_check { 'osc_gpfs':
  source => 'puppet:///modules/profile/nhc/osc_gpfs.nhc',
}
```

#### Parameters

The following parameters are available in the `nhc::custom_check` defined type:

* [`source`](#source)

##### <a name="source"></a>`source`

Data type: `Optional[String]`

The source of the custom check

Default value: ``undef``

